@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * editor.c - webkit stuff
  *
- * Copyright (C) 2005-2020 Xiphos Developer Team
+ * Copyright (C) 2005-2025 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +23,14 @@
 #include <config.h>
 #endif
 
-#ifdef USE_WEBKIT_EDITOR
+#if defined(USE_WEBKIT_EDITOR) && defined(USE_WEBKIT2)
+
+/*
+ * currently stubbed in webkit_editor.c.
+ * see comment there.
+ */
+
+#else
 
 /* X keyboard #definitions, to handle shortcuts */
 /* we must define the categories of #definitions we need. */
@@ -1138,7 +1145,7 @@ void create_editor_window(GtkWidget *scrollwindow, EDITOR *e)
 		webkit_web_view_load_string((WebKitWebView *)
 					    e->html_widget,
 					    text,
-					    "application/xhtml+xml", "utf_8",
+					    "text/html", "utf_8",
 					    "file://");
 	}
 	if (text)
