@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * webkit_editor.c - html editor using webkit
  *
- * Copyright (C) 2005-2020 Xiphos Developer Team
+ * Copyright (C) 2005-2025 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,31 @@
 
 #include <config.h>
 
-#ifdef USE_WEBKIT_EDITOR
+#if defined(USE_WEBKIT_EDITOR) && defined(USE_WEBKIT2)
+
+/* stubs for disabled editor */
+
+/* WK editor is disabled for now because its annoyingly different (from gtkhtml)
+ * API has been in the way for far too long. once this editor is figured out,
+ * the stubs will be removed and normal compilation of this file will go on.
+ */
+
+#include <glib.h>
+#include <glib/gi18n.h>
+#include "editor/webkit_editor.h"
+#include "gui/dialog.h"
+
+gint editor_create_new(const gchar *filename, const gchar *key, gint editor_type)
+{
+	gui_generic_warning(_("The editor is disabled on this platform due to missing dependencies.\nWe hope to re-enable it in a future release."));
+}
+void editor_maybe_save_all(void) {}
+void editor_load_note(EDITOR *e, const gchar *module_name, const gchar *key) {}
+void editor_sync_with_main(void) {}
+void editor_save_book(EDITOR *e) {}
+void editor_load_book(EDITOR *e) {}
+
+#else  /* !USE_WEBKIT_EDITOR || !USE_WEBKIT2 */
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -330,7 +354,7 @@ action_delete_item_activate_cb(GtkWidget *widget, EDITOR *e)
 			webkit_web_view_load_string((WebKitWebView *)
 						    e->html_widget,
 						    text,
-						    "application/xhtml+xml", "utf_8",
+						    "text/html", "utf_8",
 						    "file://");
 		}
 		if (text)
@@ -1022,7 +1046,7 @@ void editor_load_book(EDITOR *e)
 		webkit_web_view_load_string((WebKitWebView *)
 					    e->html_widget,
 					    text,
-					    "application/xhtml+xml", "utf_8",
+					    "text/html", "utf_8",
 					    "file://");
 	}
 
@@ -1110,7 +1134,7 @@ editor_load_note(EDITOR *e, const gchar *module_name, const gchar *key)
 		webkit_web_view_load_string((WebKitWebView *)
 					    e->html_widget,
 					    text,
-					    "application/xhtml+xml", "utf_8",
+					    "text/html", "utf_8",
 					    "file://");
 	}
 
@@ -1429,4 +1453,4 @@ void editor_maybe_save_all(void)
 	}
 }
 
-#endif /* USE_WEBKIT_EDITOR */
+#endif /* defined(USE_WEBKIT_EDITOR) && defined(USE_WEBKIT2) */
