@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * preferences_dialog.c - get user preferences
  *
- * Copyright (C) 2000-2020 Xiphos Developer Team
+ * Copyright (C) 2000-2025 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -76,6 +76,7 @@ struct _preferences_combo
 	GtkWidget *verse_number_size;
 	GtkWidget *special_locale;
 	GtkWidget *font_prefs;
+	GtkWidget *display_columns;
 };
 
 typedef struct _preferences_color_pickers COLOR_PICKERS;
@@ -113,6 +114,7 @@ struct _preferences_check_buttons
 	GtkWidget *prayerlist;
 	GtkWidget *statusbar;
 	GtkWidget *alternation;
+	GtkWidget *justify_margins;
 
 	GtkWidget *show_in_viewer;
 	GtkWidget *show_in_dictionary;
@@ -1185,6 +1187,29 @@ on_checkbutton8_toggled(GtkToggleButton *togglebutton, gpointer user_data)
 	settings.showsplash = gtk_toggle_button_get_active(togglebutton);
 }
 
+/******************************************************************************
+ * Name
+ *   on_justifybutton_toggled
+ *
+ * Synopsis
+ *   #include "preferences_dialog.h"
+ *   void on_justifybutton_toggled(GtkToggleButton * togglebutton, gpointer user_data)
+ *
+ * Description
+ *
+ * Return value
+ *   void
+ */
+
+void
+on_justifybutton_toggled(GtkToggleButton *togglebutton, gpointer user_data)
+{
+	xml_set_value("Xiphos", "misc", "justifymargins",
+		      (gtk_toggle_button_get_active(togglebutton) ? "1" : "0"));
+	settings.justify_margins = gtk_toggle_button_get_active(togglebutton);
+	redisplay_to_realign();
+}
+
 /******************************************************************************
  * Name
  *   on_checkbutton_scroll_toggled
@@ -1537,13 +1562,44 @@ void on_combobox1_changed(GtkComboBox *combobox, gpointer user_data)
 	settings.verse_num_font_size =
 	    atoi(settings.verse_num_font_size_str);
 	url =
-	    g_strdup_printf("sword://%s/%s", settings.MainWindowModule,
-			    settings.currentverse);
+	    g_strdup_printf("sword:///%s", settings.currentverse);
 	main_url_handler(url, TRUE);
 	g_free(url);
 	g_free(buf);
 }
 
+/******************************************************************************
+ * Name
+ *   on_columncountvalue_changed
+ *
+ * Synopsis
+ *   #include "preferences_dialog.h"
+ *   void on_columncountvalue_changed(GtkComboBox *combobox, gpointer user_data)
+ *
+ * Description
+ *   display columns has changed
+ *
+ * Return value
+ *   void
+ */
+
+void on_columncountvalue_changed(GtkComboBox *combobox, gpointer user_data)
+{
+	gchar *buf = NULL;
+	gchar *url = NULL;
+	GtkTreeIter iter;
+	GtkTreeModel *model = gtk_combo_box_get_model(combobox);
+
+	gtk_combo_box_get_active_iter(combobox, &iter);
+	gtk_tree_model_get(GTK_TREE_MODEL(model), &iter, 0, &buf, -1);
+	if (!buf)
+		return;
+	xml_set_value("Xiphos", "misc", "displaycolumns", buf);
+	settings.display_columns = atoi(buf);
+	g_free(buf);
+	redisplay_to_realign();
+}
+
 /******************************************************************************
  * Name
  *   on_basecombobox1_changed
@@ -2024,6 +2080,35 @@ on_dialog_prefs_response(GtkDialog *dialog,
 	main_update_parallel_page();
 }
 
+/******************************************************************************
+ * Name
+ *   on_dialog_prefs_close
+ *
+ * Synopsis
+ *   #include "gui/.h"
+ *   void on_dialog_prefs_close(GtkDialog * dialog, gpointer user_data)
+ *
+ * Description
+ *
+ * Return value
+ *   void
+ */
+
+void
+on_dialog_prefs_close(GtkDialog *dialog, gpointer user_data)
+{
+	settings.display_prefs = 0;
+	xml_set_value("Xiphos", "layout", "prefsopen", "0");
+
+	xml_save_settings_doc(settings.fnconfigure);
+	gtk_widget_destroy(GTK_WIDGET(dialog));
+
+	dialog_prefs = NULL;
+	speaker_window = NULL;
+	speaker_list = NULL;
+	main_update_parallel_page();
+}
+
 static GtkTreeModel *create_model(void)
 {
 	GtkTreeStore *model;
@@ -2207,6 +2292,8 @@ static void setup_check_buttons(void)
 				     settings.statusbar);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button.alternation),
 				     settings.alternation);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button.justify_margins),
+				     settings.justify_margins);
 
 	/* v-- BibleSync --v */
 	/* toggles */
@@ -2289,6 +2376,8 @@ static void setup_check_buttons(void)
 	g_signal_connect(check_button.alternation, "toggled",
 			 G_CALLBACK(on_checkbutton_alternation_toggled),
 			 NULL);
+	g_signal_connect(check_button.justify_margins, "toggled",
+			 G_CALLBACK(on_justifybutton_toggled), NULL);
 
 	/* v-- BibleSync --v */
 	g_signal_connect(check_button.bs_debug, "toggled",
@@ -2595,16 +2684,15 @@ static void ps_setup_listview()
 	if (settings.parallel_list) {
 		for (i = 0; settings.parallel_list[i]; ++i) {
 			const char *abbreviation =
-			    main_get_abbreviation(settings.parallel_list
-						      [i]);
+			    main_name_to_abbrev(settings.parallel_list[i]);
 			gtk_list_store_append(list_store, &iter);
 			gtk_list_store_set(list_store, &iter,
-					   0, main_get_module_description(settings.parallel_list[i]),
+					   0,
+					   main_get_module_description(settings.parallel_list[i]),
 					   1,
 					   (abbreviation
-						? abbreviation
-						: (gchar *)
-						  settings.parallel_list[i]),
+					    ? abbreviation
+					    : (gchar *)settings.parallel_list[i]),
 					   -1);
 		}
 	}
@@ -2701,7 +2789,7 @@ static void on_mod_sel_add_clicked(GtkWidget *button, gchar *user_data)
 		g_free(parallels);
 		return;
 	}
-	abbreviation = main_get_abbreviation(module_selected);
+	abbreviation = main_name_to_abbrev(module_selected);
 
 	model =
 	    gtk_tree_view_get_model(GTK_TREE_VIEW(parallel_select.listview));
@@ -2938,6 +3026,10 @@ static void create_preferences_dialog(void)
 			  settings.prefs_width, settings.prefs_height);
 	g_signal_connect(dialog_prefs, "response",
 			 G_CALLBACK(on_dialog_prefs_response), NULL);
+	g_signal_connect(dialog_prefs, "close",
+			 G_CALLBACK(on_dialog_prefs_close), NULL);
+	g_signal_connect(dialog_prefs, "destroy",
+			 G_CALLBACK(on_dialog_prefs_close), NULL);
 
 	/* color pickers */
 	color_picker.text_background = UI_GET_ITEM(gxml, "colorbutton1");
@@ -2959,6 +3051,7 @@ static void create_preferences_dialog(void)
 	check_button.show_devotion          = UI_GET_ITEM(gxml, "checkbutton7");
 	check_button.show_splash_screen     = UI_GET_ITEM(gxml, "checkbutton8");
 	check_button.use_chapter_scroll     = UI_GET_ITEM(gxml, "checkbutton_scroll");
+	check_button.justify_margins        = UI_GET_ITEM(gxml, "justifybutton");
 
 	check_button.use_imageresize = UI_GET_ITEM(gxml, "checkbutton_imageresize");
 #ifdef WIN32
@@ -3044,6 +3137,13 @@ static void create_preferences_dialog(void)
 	g_signal_connect(combo.base_font_size, "changed",
 			 G_CALLBACK(on_basecombobox1_changed), NULL);
 
+	/* display columns */
+	combo.display_columns = UI_GET_ITEM(gxml, "columncountvalue");
+	gtk_combo_box_set_active(GTK_COMBO_BOX(combo.display_columns),
+				 settings.display_columns - 1);
+	g_signal_connect(combo.display_columns, "changed",
+			 G_CALLBACK(on_columncountvalue_changed), NULL);
+
 	/* module combos */
 	combo.default_dictionary_module = UI_GET_ITEM(gxml, "combobox5");
 	combo.percomm_module = UI_GET_ITEM(gxml, "combobox6");
