@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * search_dialog.c - gui for searching Sword modules
  *
- * Copyright (C) 2000-2020 Xiphos Developer Team
+ * Copyright (C) 2000-2025 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -62,7 +62,7 @@
 #define SEARCHING N_("Searching the ")
 #define SMODULE N_(" Module")
 #define FINDS N_("found in ")
-#define HTML_START "<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\"><style type=\"text/css\"><!-- A { text-decoration:none } *[dir=rtl] { text-align: right; } --></style></head>"
+#define HTML_START "<html><head><meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\" /><style type=\"text/css\"><!-- A { text-decoration:none } *[dir=rtl] { text-align: right; } --></style></head>"
 
 SEARCH_DIALOG1 search1;
 
@@ -613,7 +613,7 @@ void new_range(GtkButton *button, gpointer user_data)
 	list_store = GTK_LIST_STORE(model);
 	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(search1.list_range_name));
 
-	text[0] = "[New Range]";
+	text[0] = _("[New Range]");
 	text[1] = "";
 
 	gtk_list_store_append(list_store, &iter);
@@ -1234,13 +1234,7 @@ GtkWidget *create_results_menu_advsearch(void)
 	gchar *glade_file;
 #ifdef USE_GTKBUILDER
 	GtkBuilder *gxml;
-#if GTK_CHECK_VERSION(3, 14, 0)
-	glade_file =
-	    gui_general_user_file("xi-menus-popup.gtkbuilder", FALSE);
-#else
-	glade_file =
-	    gui_general_user_file("xi-menus-popup_old.gtkbuilder", FALSE);
-#endif
+	glade_file = gui_general_user_file("xi-menus-popup.gtkbuilder", FALSE);
 #else
 	GladeXML *gxml;
 	glade_file = gui_general_user_file("xi-menus.glade", FALSE);
@@ -1361,6 +1355,7 @@ static void _add_two_text_columns(GtkTreeView *treeview)
 {
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
+	GtkAllocation allocation;
 
 	renderer = gtk_cell_renderer_text_new();
 
@@ -1368,6 +1363,12 @@ static void _add_two_text_columns(GtkTreeView *treeview)
 							  renderer,
 							  "text", 0, NULL);
 	gtk_tree_view_append_column(treeview, column);
+	gtk_widget_get_allocation(GTK_WIDGET(treeview), &allocation);
+	g_object_set(renderer, "wrap-mode", PANGO_WRAP_WORD, NULL);
+	g_object_set(renderer, "wrap-width", 2*allocation.width, NULL);
+	// using ↑↑↑ 2x width ↑↑↑ because it works and looks kinda right.
+	// we don't understand why allocation appears to be half size.
+
 	renderer = gtk_cell_renderer_text_new();
 
 	column = gtk_tree_view_column_new_with_attributes("Module",
