@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * configs.h -
  *
- * Copyright (C) 2000-2020 Xiphos Developer Team
+ * Copyright (C) 2000-2025 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,6 +36,8 @@ struct _mod_font
 	int old_font_size_value;
 	const char *new_font_size;
 	int no_font;
+	const char *columns;
+	int columns_value;
 };
 
 char *get_conf_file_item(const char *file, const char *mod_name,
