@@ -2,7 +2,7 @@
  * Xiphos Bible Study Tool
  * sidebar.cc - sidebar interface to sword
  *
- * Copyright (C) 2000-2020 Xiphos Developer Team
+ * Copyright (C) 2000-2025 Xiphos Developer Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -883,7 +883,7 @@ static void add_module_to_language_folder(GtkTreeModel *model,
 	while (valid) {
 		/* Walk through the list, reading each row */
 		gchar *str_data;
-		const gchar *abbreviation = main_get_abbreviation(module_name);
+		const gchar *abbreviation = main_name_to_abbrev(module_name);
 
 		gtk_tree_model_get(model, &iter_iter, COL_CAPTION, &str_data, -1);
 		if (!strcmp(language, str_data)) {
